mesagrid
========

.. |pypi| image:: https://img.shields.io/pypi/v/mesagrid.svg
        :target: https://pypi.python.org/pypi/mesagrid
.. |travis| image:: https://app.travis-ci.com/earlbellinger/mesagrid.svg
        :target: https://app.travis-ci.com/github/earlbellinger/mesagrid
.. |docs| image:: https://readthedocs.org/projects/mesagrid/badge/?version=latest
        :target: https://mesagrid.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status
.. |license| image:: https://img.shields.io/badge/license-MIT-orange.svg?style=flat
        :target: https://github.com/earlbellinger/mesagrid/blob/main/LICENSE
        :alt: MIT License

|pypi| |travis| |docs| |license|

A python library for parsing, analyzing, and visualizing grids of MESA tracks and models, including stellar pulsation data. 
